import CoreMotion
from PyObjCTools.TestSupport import TestCase


class TestCMError(TestCase):
    def test_constants(self):
        self.assertEqual(CoreMotion.CMErrorNULL, 100)
        self.assertEqual(CoreMotion.CMErrorDeviceRequiresMovement, 101)
        self.assertEqual(CoreMotion.CMErrorTrueNorthNotAvailable, 102)
        self.assertEqual(CoreMotion.CMErrorUnknown, 103)
        self.assertEqual(CoreMotion.CMErrorMotionActivityNotAvailable, 104)
        self.assertEqual(CoreMotion.CMErrorMotionActivityNotAuthorized, 105)
        self.assertEqual(CoreMotion.CMErrorMotionActivityNotEntitled, 106)
        self.assertEqual(CoreMotion.CMErrorInvalidParameter, 107)
        self.assertEqual(CoreMotion.CMErrorInvalidAction, 108)
        self.assertEqual(CoreMotion.CMErrorNotAvailable, 109)
        self.assertEqual(CoreMotion.CMErrorNotEntitled, 110)
        self.assertEqual(CoreMotion.CMErrorNotAuthorized, 111)
        self.assertEqual(CoreMotion.CMErrorNilData, 112)
        self.assertEqual(CoreMotion.CMErrorSize, 113)



# This file is generated by objective.metadata
#
# Last update: Thu Dec  2 21:30:09 2021
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
misc.update(
    {
        "CMQuaternion": objc.createStructType(
            "CoreMotion.CMQuaternion", b"{_CMQuaternion=dddd}", ["x", "y", "z", "w"]
        ),
        "CMMagneticField": objc.createStructType(
            "CoreMotion.CMMagneticField", b"{_CMMagneticField=ddd}", ["x", "y", "z"]
        ),
        "CMCalibratedMagneticField": objc.createStructType(
            "CoreMotion.CMCalibratedMagneticField",
            b"{_CMCalibratedMagneticField={_CMMagneticField=ddd}i}",
            ["field", "accuracy"],
        ),
        "CMRotationRate": objc.createStructType(
            "CoreMotion.CMRotationRate", b"{_CMRotationRate=ddd}", ["x", "y", "z"]
        ),
        "CMRotationMatrix": objc.createStructType(
            "CoreMotion.CMRotationMatrix",
            b"{_CMRotationMatrix=ddddddddd}",
            ["m11", "m12", "m13", "m21", "m22", "m23", "m31", "m32", "m33"],
        ),
        "CMAcceleration": objc.createStructType(
            "CoreMotion.CMAcceleration", b"{_CMAcceleration=ddd}", ["x", "y", "z"]
        ),
    }
)
constants = """$CMErrorDomain$"""
enums = """$CMAttitudeReferenceFrameXArbitraryCorrectedZVertical@2$CMAttitudeReferenceFrameXArbitraryZVertical@1$CMAttitudeReferenceFrameXMagneticNorthZVertical@4$CMAttitudeReferenceFrameXTrueNorthZVertical@8$CMAuthorizationStatusAuthorized@3$CMAuthorizationStatusDenied@2$CMAuthorizationStatusNotDetermined@0$CMAuthorizationStatusRestricted@1$CMDeviceMotionSensorLocationDefault@0$CMDeviceMotionSensorLocationHeadphoneLeft@1$CMDeviceMotionSensorLocationHeadphoneRight@2$CMErrorDeviceRequiresMovement@101$CMErrorInvalidAction@108$CMErrorInvalidParameter@107$CMErrorMotionActivityNotAuthorized@105$CMErrorMotionActivityNotAvailable@104$CMErrorMotionActivityNotEntitled@106$CMErrorNULL@100$CMErrorNilData@112$CMErrorNotAuthorized@111$CMErrorNotAvailable@109$CMErrorNotEntitled@110$CMErrorSize@113$CMErrorTrueNorthNotAvailable@102$CMErrorUnknown@103$CMFallDetectionEventUserResolutionConfirmed@0$CMFallDetectionEventUserResolutionDismissed@1$CMFallDetectionEventUserResolutionRejected@2$CMFallDetectionEventUserResolutionUnresponsive@3$CMMagneticFieldCalibrationAccuracyHigh@2$CMMagneticFieldCalibrationAccuracyLow@0$CMMagneticFieldCalibrationAccuracyMedium@1$CMMagneticFieldCalibrationAccuracyUncalibrated@-1$CMMotionActivityConfidenceHigh@2$CMMotionActivityConfidenceLow@0$CMMotionActivityConfidenceMedium@1$CMPedometerEventTypePause@0$CMPedometerEventTypeResume@1$"""
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"CMAccelerometerData",
        b"acceleration",
        {"retval": {"type": b"{_CMAcceleration=ddd}"}},
    )
    r(b"CMAltimeter", b"isAbsoluteAltitudeAvailable", {"retval": {"type": b"Z"}})
    r(b"CMAltimeter", b"isRelativeAltitudeAvailable", {"retval": {"type": b"Z"}})
    r(
        b"CMAltimeter",
        b"startAbsoluteAltitudeUpdatesToQueue:withHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"CMAltimeter",
        b"startRelativeAltitudeUpdatesToQueue:withHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(b"CMAttitude", b"quaternion", {"retval": {"type": b"{_CMQuaternion=dddd}"}})
    r(
        b"CMAttitude",
        b"rotationMatrix",
        {"retval": {"type": b"{_CMRotationMatrix=ddddddddd}"}},
    )
    r(b"CMDeviceMotion", b"gravity", {"retval": {"type": b"{_CMAcceleration=ddd}"}})
    r(
        b"CMDeviceMotion",
        b"magneticField",
        {"retval": {"type": b"{_CMCalibratedMagneticField={_CMMagneticField=ddd}i}"}},
    )
    r(
        b"CMDeviceMotion",
        b"rotationRate",
        {"retval": {"type": b"{_CMRotationRate=ddd}"}},
    )
    r(
        b"CMDeviceMotion",
        b"userAcceleration",
        {"retval": {"type": b"{_CMAcceleration=ddd}"}},
    )
    r(b"CMFallDetectionManager", b"isAvailable", {"retval": {"type": b"Z"}})
    r(
        b"CMFallDetectionManager",
        b"requestAuthorizationWithHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"q"}},
                    }
                }
            }
        },
    )
    r(b"CMGyroData", b"rotationRate", {"retval": {"type": b"{_CMRotationRate=ddd}"}})
    r(b"CMHeadphoneMotionManager", b"isDeviceMotionActive", {"retval": {"type": b"Z"}})
    r(
        b"CMHeadphoneMotionManager",
        b"isDeviceMotionAvailable",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"CMHeadphoneMotionManager",
        b"startDeviceMotionUpdatesToQueue:withHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"CMMagnetometerData",
        b"magneticField",
        {"retval": {"type": b"{_CMMagneticField=ddd}"}},
    )
    r(b"CMMotionActivity", b"automotive", {"retval": {"type": b"Z"}})
    r(b"CMMotionActivity", b"cycling", {"retval": {"type": b"Z"}})
    r(b"CMMotionActivity", b"running", {"retval": {"type": b"Z"}})
    r(b"CMMotionActivity", b"stationary", {"retval": {"type": b"Z"}})
    r(b"CMMotionActivity", b"unknown", {"retval": {"type": b"Z"}})
    r(b"CMMotionActivity", b"walking", {"retval": {"type": b"Z"}})
    r(b"CMMotionActivityManager", b"isActivityAvailable", {"retval": {"type": b"Z"}})
    r(
        b"CMMotionActivityManager",
        b"queryActivityStartingFromDate:toDate:toQueue:withHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"CMMotionActivityManager",
        b"startActivityUpdatesToQueue:withHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(b"CMMotionManager", b"isAccelerometerActive", {"retval": {"type": b"Z"}})
    r(b"CMMotionManager", b"isAccelerometerAvailable", {"retval": {"type": b"Z"}})
    r(b"CMMotionManager", b"isDeviceMotionActive", {"retval": {"type": b"Z"}})
    r(b"CMMotionManager", b"isDeviceMotionAvailable", {"retval": {"type": b"Z"}})
    r(b"CMMotionManager", b"isGyroActive", {"retval": {"type": b"Z"}})
    r(b"CMMotionManager", b"isGyroAvailable", {"retval": {"type": b"Z"}})
    r(b"CMMotionManager", b"isMagnetometerActive", {"retval": {"type": b"Z"}})
    r(b"CMMotionManager", b"isMagnetometerAvailable", {"retval": {"type": b"Z"}})
    r(
        b"CMMotionManager",
        b"setShowsDeviceMovementDisplay:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"CMMotionManager", b"showsDeviceMovementDisplay", {"retval": {"type": b"Z"}})
    r(
        b"CMMotionManager",
        b"startAccelerometerUpdatesToQueue:withHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"CMMotionManager",
        b"startDeviceMotionUpdatesToQueue:withHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"CMMotionManager",
        b"startDeviceMotionUpdatesUsingReferenceFrame:toQueue:withHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"CMMotionManager",
        b"startGyroUpdatesToQueue:withHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"CMMotionManager",
        b"startMagnetometerUpdatesToQueue:withHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(b"CMMovementDisorderManager", b"isAvailable", {"retval": {"type": b"Z"}})
    r(
        b"CMMovementDisorderManager",
        b"queryDyskineticSymptomFromDate:toDate:withHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"CMMovementDisorderManager",
        b"queryTremorFromDate:toDate:withHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(b"CMPedometer", b"isCadenceAvailable", {"retval": {"type": b"Z"}})
    r(b"CMPedometer", b"isDistanceAvailable", {"retval": {"type": b"Z"}})
    r(b"CMPedometer", b"isFloorCountingAvailable", {"retval": {"type": b"Z"}})
    r(b"CMPedometer", b"isPaceAvailable", {"retval": {"type": b"Z"}})
    r(b"CMPedometer", b"isPedometerEventTrackingAvailable", {"retval": {"type": b"Z"}})
    r(b"CMPedometer", b"isStepCountingAvailable", {"retval": {"type": b"Z"}})
    r(
        b"CMPedometer",
        b"queryPedometerDataFromDate:toDate:withHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"CMPedometer",
        b"startPedometerEventUpdatesWithHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"CMPedometer",
        b"startPedometerUpdatesFromDate:withHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"CMRotationRateData",
        b"rotationRate",
        {"retval": {"type": b"{_CMRotationRate=ddd}"}},
    )
    r(
        b"CMSensorRecorder",
        b"isAccelerometerRecordingAvailable",
        {"retval": {"type": b"Z"}},
    )
    r(b"CMSensorRecorder", b"isAuthorizedForRecording", {"retval": {"type": b"Z"}})
    r(b"CMStepCounter", b"isStepCountingAvailable", {"retval": {"type": b"Z"}})
    r(
        b"CMStepCounter",
        b"queryStepCountStartingFrom:to:toQueue:withHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"CMStepCounter",
        b"startStepCountingUpdatesToQueue:updateOn:withHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"NSObject",
        b"fallDetectionManager:didDetectEvent:completionHandler:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    },
                    "type": b"@?",
                },
            },
        },
    )
    r(
        b"NSObject",
        b"fallDetectionManagerDidChangeAuthorization:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"headphoneMotionManagerDidConnect:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"headphoneMotionManagerDidDisconnect:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



"""
Python mapping for the CoreMotion framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Foundation
import objc
from CoreMotion import _metadata

sys.modules["CoreMotion"] = mod = objc.ObjCLazyModule(
    "CoreMotion",
    "com.apple.CoreMotion",
    objc.pathForFramework("/System/Library/Frameworks/CoreMotion.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (Foundation,),
)


del sys.modules["CoreMotion._metadata"]



import CoreMotion
from PyObjCTools.TestSupport import TestCase


class TestCMGyro(TestCase):
    def test_structs(self):
        v = CoreMotion.CMRotationRate()
        self.assertEqual(v.x, 0.0)
        self.assertEqual(v.y, 0.0)
        self.assertEqual(v.z, 0.0)
        self.assertPickleRoundTrips(v)



import CoreMotion
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCMErrorDomain(TestCase):
    @min_os_level("10.15")
    def test_constants(self):
        self.assertIsInstance(CoreMotion.CMErrorDomain, str)



import CoreMotion
from PyObjCTools.TestSupport import TestCase, min_os_level

CMPedometerHandler = b"v@"
CMPedometerEventHandler = b"v@@"


class TestCMPedometer(TestCase):
    def test_constants(self):
        self.assertEqual(CoreMotion.CMPedometerEventTypePause, 0)
        self.assertEqual(CoreMotion.CMPedometerEventTypeResume, 1)

    @min_os_level("10.15")
    def test_methods10_15(self):
        self.assertResultIsBOOL(CoreMotion.CMPedometer.isStepCountingAvailable)
        self.assertResultIsBOOL(CoreMotion.CMPedometer.isDistanceAvailable)
        self.assertResultIsBOOL(CoreMotion.CMPedometer.isFloorCountingAvailable)
        self.assertResultIsBOOL(CoreMotion.CMPedometer.isPaceAvailable)

        self.assertArgIsBlock(
            CoreMotion.CMPedometer.queryPedometerDataFromDate_toDate_withHandler_,
            2,
            CMPedometerHandler,
        )
        self.assertArgIsBlock(
            CoreMotion.CMPedometer.startPedometerUpdatesFromDate_withHandler_,
            1,
            CMPedometerHandler,
        )
        self.assertArgIsBlock(
            CoreMotion.CMPedometer.startPedometerEventUpdatesWithHandler_,
            0,
            CMPedometerEventHandler,
        )



import CoreMotion
from PyObjCTools.TestSupport import TestCase


class TestCMMotionActivity(TestCase):
    def test_constants(self):
        self.assertEqual(CoreMotion.CMMotionActivityConfidenceLow, 0)
        self.assertEqual(CoreMotion.CMMotionActivityConfidenceMedium, 1)
        self.assertEqual(CoreMotion.CMMotionActivityConfidenceHigh, 2)



import CoreMotion
from PyObjCTools.TestSupport import TestCase


class TestCMAccelerometer(TestCase):
    def test_structs(self):
        v = CoreMotion.CMRotationMatrix()
        self.assertEqual(v.m11, 0.0)
        self.assertEqual(v.m12, 0.0)
        self.assertEqual(v.m13, 0.0)
        self.assertEqual(v.m21, 0.0)
        self.assertEqual(v.m22, 0.0)
        self.assertEqual(v.m23, 0.0)
        self.assertEqual(v.m31, 0.0)
        self.assertEqual(v.m32, 0.0)
        self.assertEqual(v.m33, 0.0)
        self.assertPickleRoundTrips(v)

        v = CoreMotion.CMQuaternion()
        self.assertEqual(v.x, 0.0)
        self.assertEqual(v.y, 0.0)
        self.assertEqual(v.z, 0.0)
        self.assertEqual(v.w, 0.0)
        self.assertPickleRoundTrips(v)

    def test_constants(self):
        self.assertEqual(CoreMotion.CMAttitudeReferenceFrameXArbitraryZVertical, 1 << 0)
        self.assertEqual(
            CoreMotion.CMAttitudeReferenceFrameXArbitraryCorrectedZVertical, 1 << 1
        )
        self.assertEqual(
            CoreMotion.CMAttitudeReferenceFrameXMagneticNorthZVertical, 1 << 2
        )
        self.assertEqual(CoreMotion.CMAttitudeReferenceFrameXTrueNorthZVertical, 1 << 3)
